# Copyright (C) 2014 Mohammad H. Ferdosi and V. Boerner
#
# HSPhase is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.

# HSPhase program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.

# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http:#www.gnu.org/licenses/>.

ohg <- function(genotypeMatrix)
{
  cm <- genotypeMatrix - (floor(genotypeMatrix/9) * 8)
  result <- (floor(cm/2) %*%  t(round(((cm) - 2)/2))) * (-1)
  t(result) + result
}
